{% extends extend_str %}
{% load aux_tags %}

{% block content %}

<form method="post">{% csrf_token %}
    <p>
    <h4>Are you sure you want to delete this "{{ object|render_class_name }}" instance?</h4>
    <br>
    <h5><b> {{ object }}</b></h5>
    <br>
    <b><font color='red'>This cannot be undone.</font></b>
    </p>
    <input class="btn btn-primary" name="submit" type="submit" value="Confirm">
    <input class="btn btn-primary btn-warning" name="cancel" type="submit" value="Cancel" onclick="history.back()">
</form>

{% endblock content %}